@@ -560,7 +560,7 @@ class OrderDisorderedStructureTransformation(AbstractTransformation):
                  "structure": s_copy.get_sorted_structure()})
 
         if return_ranked_list:
-            return self._all_structures
+            return self._all_structures[:num_to_return]
         else:
             return self._all_structures[0]["structure"]
 
@@ -678,17 +678,22 @@ class PerturbStructureTransformation(AbstractTransformation):
     directions. Used for breaking symmetries.
 
     Args:
-        amplitude (float): Amplitude of perturbation in angstroms. All sites
-            will be perturbed by exactly that amplitude in a random direction.
+        distance (float): Distance of perturbation in angstroms. All sites
+            will be perturbed by exactly that distance in a random direction.
+        min_distance (None, int, or float): if None, all displacements will be
+            equidistant. If int or float, perturb each site a
+            distance drawn from the uniform distribution between
+            'min_distance' and 'distance'.
     """
 
-    def __init__(self, amplitude=0.01):
+    def __init__(self, distance=0.01, min_distance=None):
 
-        self.amplitude = amplitude
+        self.distance = distance
+        self.min_distance = min_distance
 
     def apply_transformation(self, structure):
         s = structure.copy()
-        s.perturb(self.amplitude)
+        s.perturb(self.distance, min_distance=self.min_distance)
         return s
 
     def __str__(self):
